@@ -1,5 +1,6 @@
 import asyncio
 import logging
+from typing import Optional
 
 import pendulum
 from komoutils.core import safe_ensure_future, KomoBase
@@ -19,9 +20,18 @@ class Symbol(KomoBase):
         self.asset = str(self.symbol).split("_")[2]
         self.cursor: Cursor = Cursor(symbol=self.symbol)
 
+        self.trades_data_task: Optional[asyncio.Task] = None
+
     def start(self):
         safe_ensure_future(self.cursor.start())
-        safe_ensure_future(self.trades_data_loop())
+        self.trades_data_task = safe_ensure_future(self.trades_data_loop())
+
+    def stop(self):
+        self.cursor.stop()
+        if self.trades_data_task is not None:
+            self.trades_data_task.cancel()
+            self.trades_data_task = None
+            del self.trades_data_task
 
     async def trades_data_loop(self):
         self.log_with_clock(log_level=logging.INFO, msg=f"Started trades data loop for {self.symbol}. ")
@@ -59,7 +69,8 @@ class Symbol(KomoBase):
                     self.cursor.status = CursorStatus.STARTED
 
                 if timestamp not in self.cursor.ticks:
-                    print(f"Creating Timestamp Not Available {timestamp} {trade['timestamp_at_exchange']} {self.symbol}".upper())
+                    print(
+                        f"Creating Timestamp Not Available {timestamp} {trade['timestamp_at_exchange']} {self.symbol}".upper())
                     self.cursor.ticks[timestamp] = Tick(symbol=self.symbol, stamp=timestamp)
 
                 self.input_trading_data_queue.task_done()
