@@ -57,7 +57,9 @@ class IntervaledTradingSymbolExecutor(KomoBase):
         self.status = Status.EPOCH_RUNNING
 
     def stop(self):
-        pass
+        self.orchestrator.stop()
+        self.status = Status.EPOCH_COMPLETE
+        self.log_with_clock(log_level=logging.INFO, msg=f"Epoch complete for {self.chain} {self.epoch}. ")
 
     def set_tso_data(self, asset_price_data: AssetPriceData):
         self.orchestrator.tso_price_set(chain=asset_price_data.chain,
@@ -69,8 +71,7 @@ class IntervaledTradingSymbolExecutor(KomoBase):
         prices, returns = self.orchestrator.generate_chain_epoch_record(chain=self.chain, epoch=self.epoch)
         self.results["prices"] = prices.copy()
         self.results["returns"] = returns.copy()
-        self.status = Status.EPOCH_COMPLETE
-        self.log_with_clock(log_level=logging.INFO, msg=f"Epoch complete for {self.chain} {self.epoch}. ")
+        self.stop()
 
 
 
